powered by
Create simple Gauge Charts
c3_gauge( c3, label = NULL, min = 0, max = 100, units = NULL, width = NULL, pattern = c("#FF0000", "#F97600", "#F6C600", "#60B044"), threshold = list(unit = "value", max = 100, values = c(30, 60, 90, 100)), height = NULL, ... )
c3
c3 htmlwidget object
list with options:
boolean
function, wrap in JS()
numeric
character appended to numeric value
integer pixel width of the arc
character vector or palette of colors
character one of 'percent', 'value'
numeric vector of threshold values for color change
integer pixel height of the chart. Proportion of gauge never changes so height scales with width despite this setting.
additional values passed to the gauge, color and size objects
data.frame(data=10) %>% c3() %>% c3_gauge(title = 'Colors')
Run the code above in your browser using DataLab