Learn R Programming

c3 (version 0.3.2)

c3_selection: Data Select

Description

Define options for selecting data within the plot area

Usage

c3_selection(
  c3,
  enabled = FALSE,
  grouped = FALSE,
  multiple = FALSE,
  draggable = FALSE,
  isselectable = JS("function () { return true; }"),
  ...
)

Value

c3

Arguments

c3

c3 htmlwidget object

enabled

boolean

grouped

boolean

multiple

boolean

draggable

boolean

isselectable

character js function, wrap character or character vector in JS()

...

additional options passed to data selection object

Examples

Run this code
data.frame(a = c(1,2,3,2), b = c(2,3,1,5)) %>%
  c3() %>%
  c3_selection(enabled = TRUE,
               multiple = TRUE)

Run the code above in your browser using DataLab