check_stacked: Check groups for stacked plots
Description
For plots where stacking is required this function will
define the columns to be stacked based on column headers.
Usage
check_stacked(c3, stacked)
Arguments
- c3
c3 htmlwidget object
- stacked
boolean