Learn R Programming

c3 (version 0.3.2)

subchart: Add Subchart

Description

Subcharts are defined in multiple axis by passing a single `data.frame`. Subcharts are listed as an experimental feature in the C3 documentation).

Usage

subchart(c3, height = 20, onbrush = NULL)

# S3 method for c3 subchart(c3, height = 20, onbrush = NULL)

Value

c3

Arguments

c3

c3 htmlwidget object

height

integer pixels

onbrush

character js function, wrap character or character vector in JS()

See Also

Other c3: RColorBrewer(), c3(), grid(), legend(), region(), tooltip(), xAxis(), zoom()

Examples

Run this code
data.frame(a = abs(rnorm(20) * 10),
           b = abs(rnorm(20) * 10),
           date = seq(as.Date("2014-01-01"), by = "month", length.out = 20)) %>%
     c3(x = 'date') %>%
     subchart(height = 20, onbrush = 'function (domain) { console.log(domain) }')

Run the code above in your browser using DataLab