Learn R Programming

c3 (version 0.3.2)

tickAxis: Axis Tick Options

Description

Modify axis tick formatting options

Usage

tickAxis(
  c3,
  axis,
  centered = TRUE,
  format = NULL,
  culling = NULL,
  count = NULL,
  fit = TRUE,
  values = NULL,
  rotate = 0,
  outer = TRUE,
  ...
)

Value

c3

Arguments

c3

c3 htmlwidget object

axis

character 'x', 'y' or 'y2' axis

centered

boolean (x-axis only)

format

character js function, wrap character or character vector in JS()

culling

boolean or list defining number of ticks `list(max = 5)` this option effects tick labels (x-axis only)

count

integer number of ticks to display. This effects tick lines and labels

fit

boolean position ticks evenly or set to values (x-axis only)

values

vector. Must match axis format type

rotate

integer degrees to rotate labels (x-axis only)

outer

boolean show axis outer tick

...

additional options passed to axis tick object

Examples

Run this code
data.frame(a = c(1,2,3,2), b = c(2,4,1,5)) %>%
  c3() %>%
  tickAxis('y', values = c(1,3))

Run the code above in your browser using DataLab