Learn R Programming

c3 (version 0.3.2)

zoom: Add C3 Zoom

Description

Enable chart Zoom.

Usage

zoom(
  c3,
  enabled = TRUE,
  rescale = NULL,
  extent = NULL,
  onzoom = NULL,
  onzoomstart = NULL,
  onzoomend = NULL,
  ...
)

# S3 method for c3 zoom( c3, enabled = TRUE, rescale = NULL, extent = NULL, onzoom = NULL, onzoomstart = NULL, onzoomend = NULL, ... )

Value

c3

Arguments

c3

c3 htmlwidget object

enabled

boolean default is TRUE

rescale

boolean rescale axis when zooming

extent

numeric vector

onzoom

character js function, wrap character or character vector in JS()

onzoomstart

character js function, wrap character or character vector in JS()

onzoomend

character js function, wrap character or character vector in JS()

...

additional options passed to the zoom object

See Also

Other c3: RColorBrewer(), c3(), grid(), legend(), region(), subchart(), tooltip(), xAxis()

Examples

Run this code
data.frame(a = abs(rnorm(20) * 10),
           b = abs(rnorm(20) * 10)) %>%
     c3() %>%
     zoom()

Run the code above in your browser using DataLab