powered by
Define options for selecting data within the plot area
c3_selection( c3, enabled = FALSE, grouped = FALSE, multiple = FALSE, draggable = FALSE, isselectable = JS("function () { return true; }"), ... )
c3
c3 htmlwidget object
boolean
character js function, wrap character or character vector in JS()
additional options passed to data selection object
data.frame(a = c(1,2,3,2), b = c(2,3,1,5)) %>% c3() %>% c3_selection(enabled = TRUE, multiple = TRUE)
Run the code above in your browser using DataLab