powered by
Regions are defined in multiple axis by passing a single `data.frame`
region(c3, regions)# S3 method for c3 region(c3, regions)
# S3 method for c3 region(c3, regions)
c3
c3 htmlwidget object
data.frame with columns listed below. Any columns can be missing but results may be unexpected.
character one of 'x', 'y', 'y2'
numeric but must match defined axis type
character css class
Other c3: RColorBrewer(), c3(), grid(), legend(), subchart(), tooltip(), xAxis(), zoom()
RColorBrewer()
c3()
grid()
legend()
subchart()
tooltip()
xAxis()
zoom()
mtcars %>% c3(x = 'mpg', y = 'wt', group = 'cyl') %>% c3_scatter() %>% region(data.frame(axis = 'x', start = 17, end = 21))
Run the code above in your browser using DataLab